.. -*- coding: utf-8 -*-

.. _Part1:

--------------------------
Introduction to *CubicWeb*
--------------------------

This first part of the book offers different reading path to
discover the *CubicWeb* framework, provides a tutorial to get a quick
overview of its features and lists its key concepts.


.. toctree::
   :maxdepth: 2
   :numbered:

   history
   concepts.rst
